@@ -25,34 +25,36 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V20::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V20::Resources::Campaign;
-use Google::Ads::GoogleAds::V20::Resources::DynamicSearchAdsSetting;
-use Google::Ads::GoogleAds::V20::Resources::AdGroup;
-use Google::Ads::GoogleAds::V20::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V20::Resources::Ad;
-use Google::Ads::GoogleAds::V20::Resources::AdGroupCriterion;
-use Google::Ads::GoogleAds::V20::Common::ManualCpc;
-use Google::Ads::GoogleAds::V20::Common::ExpandedDynamicSearchAdInfo;
-use Google::Ads::GoogleAds::V20::Common::WebpageInfo;
-use Google::Ads::GoogleAds::V20::Common::WebpageConditionInfo;
-use Google::Ads::GoogleAds::V20::Enums::BudgetDeliveryMethodEnum   qw(STANDARD);
-use Google::Ads::GoogleAds::V20::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
-use Google::Ads::GoogleAds::V20::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V20::Enums::AdGroupStatusEnum;
-use Google::Ads::GoogleAds::V20::Enums::AdGroupTypeEnum qw(SEARCH_DYNAMIC_ADS);
-use Google::Ads::GoogleAds::V20::Enums::AdGroupAdStatusEnum;
-use Google::Ads::GoogleAds::V20::Enums::AdGroupCriterionStatusEnum;
-use Google::Ads::GoogleAds::V20::Enums::WebpageConditionOperandEnum
+use Google::Ads::GoogleAds::V21::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V21::Resources::Campaign;
+use Google::Ads::GoogleAds::V21::Resources::DynamicSearchAdsSetting;
+use Google::Ads::GoogleAds::V21::Resources::AdGroup;
+use Google::Ads::GoogleAds::V21::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V21::Resources::Ad;
+use Google::Ads::GoogleAds::V21::Resources::AdGroupCriterion;
+use Google::Ads::GoogleAds::V21::Common::ManualCpc;
+use Google::Ads::GoogleAds::V21::Common::ExpandedDynamicSearchAdInfo;
+use Google::Ads::GoogleAds::V21::Common::WebpageInfo;
+use Google::Ads::GoogleAds::V21::Common::WebpageConditionInfo;
+use Google::Ads::GoogleAds::V21::Enums::BudgetDeliveryMethodEnum   qw(STANDARD);
+use Google::Ads::GoogleAds::V21::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
+use Google::Ads::GoogleAds::V21::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::AdGroupStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::AdGroupTypeEnum qw(SEARCH_DYNAMIC_ADS);
+use Google::Ads::GoogleAds::V21::Enums::AdGroupAdStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::AdGroupCriterionStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::WebpageConditionOperandEnum
   qw(URL PAGE_TITLE);
+use Google::Ads::GoogleAds::V21::Enums::EuPoliticalAdvertisingStatusEnum
+  qw(DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING);
 use
-  Google::Ads::GoogleAds::V20::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation;
-use Google::Ads::GoogleAds::V20::Services::AdGroupService::AdGroupOperation;
-use Google::Ads::GoogleAds::V20::Services::AdGroupAdService::AdGroupAdOperation;
+  Google::Ads::GoogleAds::V21::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V21::Services::AdGroupService::AdGroupOperation;
+use Google::Ads::GoogleAds::V21::Services::AdGroupAdService::AdGroupAdOperation;
 use
-  Google::Ads::GoogleAds::V20::Services::AdGroupCriterionService::AdGroupCriterionOperation;
-use Google::Ads::GoogleAds::V20::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V21::Services::AdGroupCriterionService::AdGroupCriterionOperation;
+use Google::Ads::GoogleAds::V21::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -92,7 +94,7 @@ sub create_campaign_budget {
 
   # Create a campaign budget.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V20::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V21::Resources::CampaignBudget->new({
       name           => "Interplanetary Cruise Budget #" . uniqid(),
       deliveryMethod => STANDARD,
       amountMicros   => 50000000
@@ -100,7 +102,7 @@ sub create_campaign_budget {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V20::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V21::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({create => $campaign_budget});
 
   # Add the campaign budget.
@@ -121,15 +123,15 @@ sub create_campaign {
   my ($api_client, $customer_id, $campaign_budget_resource_name) = @_;
 
   # Create a campaign.
-  my $campaign = Google::Ads::GoogleAds::V20::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V21::Resources::Campaign->new({
       name                   => "Interplanetary Cruise #" . uniqid(),
       advertisingChannelType => SEARCH,
-      status => Google::Ads::GoogleAds::V20::Enums::CampaignStatusEnum::PAUSED,
-      manualCpc      => Google::Ads::GoogleAds::V20::Common::ManualCpc->new(),
+      status => Google::Ads::GoogleAds::V21::Enums::CampaignStatusEnum::PAUSED,
+      manualCpc      => Google::Ads::GoogleAds::V21::Common::ManualCpc->new(),
       campaignBudget => $campaign_budget_resource_name,
       # Enable the campaign for DSAs.
       dynamicSearchAdsSetting =>
-        Google::Ads::GoogleAds::V20::Resources::DynamicSearchAdsSetting->new({
+        Google::Ads::GoogleAds::V21::Resources::DynamicSearchAdsSetting->new({
           domainName   => "example.com",
           languageCode => "en"
         }
@@ -138,11 +140,16 @@ sub create_campaign {
       # now and ending a month from now.
       startDate => strftime("%Y%m%d", localtime(time + 60 * 60 * 24)),
       endDate   => strftime("%Y%m%d", localtime(time + 60 * 60 * 24 * 30)),
+      # Declare whether or not this campaign serves political ads targeting the EU.
+      # Valid values are CONTAINS_EU_POLITICAL_ADVERTISING and
+      # DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING.
+      containsEuPoliticalAdvertising =>
+        DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING
     });
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation->
     new({create => $campaign});
 
   # Add the campaign.
@@ -164,10 +171,10 @@ sub create_ad_group {
   my ($api_client, $customer_id, $campaign_resource_name) = @_;
 
   # Construct an ad group and set an optional CPC value.
-  my $ad_group = Google::Ads::GoogleAds::V20::Resources::AdGroup->new({
+  my $ad_group = Google::Ads::GoogleAds::V21::Resources::AdGroup->new({
     name     => "Earth to Mars Cruises #" . uniqid(),
     campaign => $campaign_resource_name,
-    status   => Google::Ads::GoogleAds::V20::Enums::AdGroupStatusEnum::PAUSED,
+    status   => Google::Ads::GoogleAds::V21::Enums::AdGroupStatusEnum::PAUSED,
     type     => SEARCH_DYNAMIC_ADS,
     trackingUrlTemplate =>
       "http://tracker.examples.com/traveltracker/{escapedlpurl}",
@@ -176,7 +183,7 @@ sub create_ad_group {
 
   # Create an ad group operation.
   my $ad_group_operation =
-    Google::Ads::GoogleAds::V20::Services::AdGroupService::AdGroupOperation->
+    Google::Ads::GoogleAds::V21::Services::AdGroupService::AdGroupOperation->
     new({create => $ad_group});
 
   # Add the ad group.
@@ -198,19 +205,19 @@ sub create_expanded_dsa {
   my ($api_client, $customer_id, $ad_group_resource_name) = @_;
 
   # Create an ad group ad.
-  my $ad_group_ad = Google::Ads::GoogleAds::V20::Resources::AdGroupAd->new({
+  my $ad_group_ad = Google::Ads::GoogleAds::V21::Resources::AdGroupAd->new({
       adGroup => $ad_group_resource_name,
-      status => Google::Ads::GoogleAds::V20::Enums::AdGroupAdStatusEnum::PAUSED,
-      ad     => Google::Ads::GoogleAds::V20::Resources::Ad->new({
+      status => Google::Ads::GoogleAds::V21::Enums::AdGroupAdStatusEnum::PAUSED,
+      ad     => Google::Ads::GoogleAds::V21::Resources::Ad->new({
           expandedDynamicSearchAd =>
-            Google::Ads::GoogleAds::V20::Common::ExpandedDynamicSearchAdInfo->
+            Google::Ads::GoogleAds::V21::Common::ExpandedDynamicSearchAdInfo->
             new({
               description => "Buy tickets now!"
             })})});
 
   # Create an ad group ad operation.
   my $ad_group_ad_operation =
-    Google::Ads::GoogleAds::V20::Services::AdGroupAdService::AdGroupAdOperation
+    Google::Ads::GoogleAds::V21::Services::AdGroupAdService::AdGroupAdOperation
     ->new({create => $ad_group_ad});
 
   # Add the ad group ad.
@@ -233,28 +240,28 @@ sub add_web_page_criterion {
 
   # Create an ad group criterion.
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V20::Resources::AdGroupCriterion->new({
+    Google::Ads::GoogleAds::V21::Resources::AdGroupCriterion->new({
       adGroup => $ad_group_resource_name,
       status  =>
-        Google::Ads::GoogleAds::V20::Enums::AdGroupCriterionStatusEnum::PAUSED,
+        Google::Ads::GoogleAds::V21::Enums::AdGroupCriterionStatusEnum::PAUSED,
       cpcBidMicros => 10000000,
-      webpage      => Google::Ads::GoogleAds::V20::Common::WebpageInfo->new({
+      webpage      => Google::Ads::GoogleAds::V21::Common::WebpageInfo->new({
           criterionName => "Special Offers",
           conditions    => [
-            Google::Ads::GoogleAds::V20::Common::WebpageConditionInfo->new({
+            Google::Ads::GoogleAds::V21::Common::WebpageConditionInfo->new({
                 operand  => URL,
                 argument => "/specialoffers"
 
               }
             ),
-            Google::Ads::GoogleAds::V20::Common::WebpageConditionInfo->new({
+            Google::Ads::GoogleAds::V21::Common::WebpageConditionInfo->new({
                 operand  => PAGE_TITLE,
                 argument => "Special Offers"
               })]})});
 
   # Create an ad group criterion operation.
   my $ad_group_criterion_operation =
-    Google::Ads::GoogleAds::V20::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V21::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({create => $ad_group_criterion});
 
   # Add the ad group criterion.
