@@ -28,55 +28,57 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
-use Google::Ads::GoogleAds::V20::Resources::Ad;
-use Google::Ads::GoogleAds::V20::Resources::AdGroup;
-use Google::Ads::GoogleAds::V20::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V20::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V20::Resources::Campaign;
-use Google::Ads::GoogleAds::V20::Resources::CampaignCriterion;
-use Google::Ads::GoogleAds::V20::Resources::PhoneNumber;
-use Google::Ads::GoogleAds::V20::Resources::SmartCampaignSetting;
-use Google::Ads::GoogleAds::V20::Common::AdScheduleInfo;
-use Google::Ads::GoogleAds::V20::Common::KeywordThemeInfo;
-use Google::Ads::GoogleAds::V20::Common::LocationInfo;
-use Google::Ads::GoogleAds::V20::Common::SmartCampaignAdInfo;
-use Google::Ads::GoogleAds::V20::Common::AdTextAsset;
-use Google::Ads::GoogleAds::V20::Enums::AdGroupTypeEnum qw(SMART_CAMPAIGN_ADS);
-use Google::Ads::GoogleAds::V20::Enums::AdTypeEnum      qw(SMART_CAMPAIGN_AD);
-use Google::Ads::GoogleAds::V20::Enums::AdvertisingChannelTypeEnum qw(SMART);
-use Google::Ads::GoogleAds::V20::Enums::AdvertisingChannelSubTypeEnum;
-use Google::Ads::GoogleAds::V20::Enums::BudgetTypeEnum;
-use Google::Ads::GoogleAds::V20::Enums::CampaignStatusEnum       qw(PAUSED);
-use Google::Ads::GoogleAds::V20::Enums::DayOfWeekEnum            qw(MONDAY);
-use Google::Ads::GoogleAds::V20::Enums::MinuteOfHourEnum         qw(ZERO);
-use Google::Ads::GoogleAds::V20::Enums::ProximityRadiusUnitsEnum qw(MILES);
-use Google::Ads::GoogleAds::V20::Services::AdGroupService::AdGroupOperation;
-use Google::Ads::GoogleAds::V20::Services::AdGroupAdService::AdGroupAdOperation;
+use Google::Ads::GoogleAds::V21::Resources::Ad;
+use Google::Ads::GoogleAds::V21::Resources::AdGroup;
+use Google::Ads::GoogleAds::V21::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V21::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V21::Resources::Campaign;
+use Google::Ads::GoogleAds::V21::Resources::CampaignCriterion;
+use Google::Ads::GoogleAds::V21::Resources::PhoneNumber;
+use Google::Ads::GoogleAds::V21::Resources::SmartCampaignSetting;
+use Google::Ads::GoogleAds::V21::Common::AdScheduleInfo;
+use Google::Ads::GoogleAds::V21::Common::KeywordThemeInfo;
+use Google::Ads::GoogleAds::V21::Common::LocationInfo;
+use Google::Ads::GoogleAds::V21::Common::SmartCampaignAdInfo;
+use Google::Ads::GoogleAds::V21::Common::AdTextAsset;
+use Google::Ads::GoogleAds::V21::Enums::AdGroupTypeEnum qw(SMART_CAMPAIGN_ADS);
+use Google::Ads::GoogleAds::V21::Enums::AdTypeEnum      qw(SMART_CAMPAIGN_AD);
+use Google::Ads::GoogleAds::V21::Enums::AdvertisingChannelTypeEnum qw(SMART);
+use Google::Ads::GoogleAds::V21::Enums::AdvertisingChannelSubTypeEnum;
+use Google::Ads::GoogleAds::V21::Enums::BudgetTypeEnum;
+use Google::Ads::GoogleAds::V21::Enums::CampaignStatusEnum       qw(PAUSED);
+use Google::Ads::GoogleAds::V21::Enums::DayOfWeekEnum            qw(MONDAY);
+use Google::Ads::GoogleAds::V21::Enums::MinuteOfHourEnum         qw(ZERO);
+use Google::Ads::GoogleAds::V21::Enums::ProximityRadiusUnitsEnum qw(MILES);
+use Google::Ads::GoogleAds::V21::Enums::EuPoliticalAdvertisingStatusEnum
+  qw(DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING);
+use Google::Ads::GoogleAds::V21::Services::AdGroupService::AdGroupOperation;
+use Google::Ads::GoogleAds::V21::Services::AdGroupAdService::AdGroupAdOperation;
 use
-  Google::Ads::GoogleAds::V20::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation;
+  Google::Ads::GoogleAds::V21::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation;
 use
-  Google::Ads::GoogleAds::V20::Services::CampaignCriterionService::CampaignCriterionOperation;
-use Google::Ads::GoogleAds::V20::Services::GoogleAdsService::MutateOperation;
+  Google::Ads::GoogleAds::V21::Services::CampaignCriterionService::CampaignCriterionOperation;
+use Google::Ads::GoogleAds::V21::Services::GoogleAdsService::MutateOperation;
 use
-  Google::Ads::GoogleAds::V20::Services::KeywordThemeConstantService::SuggestKeywordThemeConstantsRequest;
+  Google::Ads::GoogleAds::V21::Services::KeywordThemeConstantService::SuggestKeywordThemeConstantsRequest;
 use
-  Google::Ads::GoogleAds::V20::Services::SmartCampaignSettingService::SmartCampaignSettingOperation;
+  Google::Ads::GoogleAds::V21::Services::SmartCampaignSettingService::SmartCampaignSettingOperation;
 use
-  Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::BusinessContext;
+  Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::BusinessContext;
 use
-  Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::KeywordTheme;
+  Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::KeywordTheme;
 use
-  Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::LocationList;
+  Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::LocationList;
 use
-  Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::SmartCampaignSuggestionInfo;
+  Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::SmartCampaignSuggestionInfo;
 use
-  Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::SuggestKeywordThemesRequest;
+  Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::SuggestKeywordThemesRequest;
 use
-  Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::SuggestSmartCampaignAdRequest;
+  Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::SuggestSmartCampaignAdRequest;
 use
-  Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::SuggestSmartCampaignBudgetOptionsRequest;
-use Google::Ads::GoogleAds::V20::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::SuggestSmartCampaignBudgetOptionsRequest;
+use Google::Ads::GoogleAds::V21::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -227,7 +229,7 @@ sub _get_keyword_theme_suggestions {
 
   my $response =
     $api_client->SmartCampaignSuggestService()->suggest_keyword_themes(
-    Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::SuggestKeywordThemesRequest
+    Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::SuggestKeywordThemesRequest
       ->new({
         customerId     => $customer_id,
         suggestionInfo => $suggestion_info
@@ -249,7 +251,7 @@ sub _get_keyword_text_auto_completions {
   my ($api_client, $keyword_text) = @_;
 
   my $response = $api_client->KeywordThemeConstantService()->suggest(
-    Google::Ads::GoogleAds::V20::Services::KeywordThemeConstantService::SuggestKeywordThemeConstantsRequest
+    Google::Ads::GoogleAds::V21::Services::KeywordThemeConstantService::SuggestKeywordThemeConstantsRequest
       ->new({
         queryText    => $keyword_text,
         countryCode  => COUNTRY_CODE,
@@ -264,7 +266,7 @@ sub _get_keyword_text_auto_completions {
   my $keyword_themes = [];
   foreach my $keyword_theme_constant (@{$response->{keywordThemeConstants}}) {
     push @$keyword_themes,
-      Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::KeywordTheme
+      Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::KeywordTheme
       ->new({
         keywordThemeConstant => $keyword_theme_constant
       });
@@ -279,7 +281,7 @@ sub _get_keyword_text_auto_completions {
 sub _get_free_form_keyword_theme_info {
   my ($free_form_keyword_text) = @_;
 
-  return Google::Ads::GoogleAds::V20::Common::KeywordThemeInfo->new({
+  return Google::Ads::GoogleAds::V21::Common::KeywordThemeInfo->new({
     freeFormKeywordTheme => $free_form_keyword_text
   });
 }
@@ -293,12 +295,12 @@ sub _map_keyword_themes_to_keyword_infos {
   foreach my $keyword_theme (@$keyword_themes) {
     if (defined $keyword_theme->{keywordThemeConstant}) {
       push @$keyword_theme_infos,
-        Google::Ads::GoogleAds::V20::Common::KeywordThemeInfo->new({
+        Google::Ads::GoogleAds::V21::Common::KeywordThemeInfo->new({
           keywordThemeConstant =>
             $keyword_theme->{keywordThemeConstant}{resourceName}});
     } elsif (defined $keyword_theme->{freeFormKeywordTheme}) {
       push @$keyword_theme_infos,
-        Google::Ads::GoogleAds::V20::Common::KeywordThemeInfo->new({
+        Google::Ads::GoogleAds::V21::Common::KeywordThemeInfo->new({
           freeFormKeywordTheme => $keyword_theme->{freeFormKeywordTheme}});
     } else {
       die "A malformed KeywordTheme was encountered: $keyword_theme";
@@ -319,7 +321,7 @@ sub _get_smart_campaign_suggestion_info {
   my ($business_profile_location, $business_name) = @_;
 
   my $suggestion_info =
-    Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::SmartCampaignSuggestionInfo
+    Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::SmartCampaignSuggestionInfo
     ->new({
       # Add the URL of the campaign's landing page.
       finalUrl => LANDING_PAGE_URL,
@@ -329,8 +331,8 @@ sub _get_smart_campaign_suggestion_info {
       # It's also possible to provide a geographic proximity using the
       # "proximity" field on suggestion_info, for example:
       #
-      # proximity => Google::Ads::GoogleAds::V20::Common::ProximityInfo->new({
-      #     address => Google::Ads::GoogleAds::V20::Common::AddressInfo->new({
+      # proximity => Google::Ads::GoogleAds::V21::Common::ProximityInfo->new({
+      #     address => Google::Ads::GoogleAds::V21::Common::AddressInfo->new({
       #         postalCode     => "INSERT_POSTAL_CODE",
       #         provinceCode   => "INSERT_PROVINCE_CODE",
       #         countryCode    => "INSERT_COUNTRY_CODE",
@@ -348,7 +350,7 @@ sub _get_smart_campaign_suggestion_info {
       # For more information on proximities see:
       # https://developers.google.com/google-ads/api/reference/rpc/latest/ProximityInfo
       locationList =>
-        Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::LocationList
+        Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::LocationList
         ->new(
         )});
 
@@ -356,10 +358,10 @@ sub _get_smart_campaign_suggestion_info {
   # object. You have the option of providing multiple locations when using
   # location-based suggestions.
   push @{$suggestion_info->{locationList}{locations}},
-    Google::Ads::GoogleAds::V20::Common::LocationInfo->new({
+    Google::Ads::GoogleAds::V21::Common::LocationInfo->new({
       # Set the location to the resource name of the given geo target constant.
       geoTargetConstant =>
-        Google::Ads::GoogleAds::V20::Utils::ResourceNames::geo_target_constant(
+        Google::Ads::GoogleAds::V21::Utils::ResourceNames::geo_target_constant(
         GEO_TARGET_CONSTANT)});
 
   # Set one of the business_profile_location or business_name, whichever is provided.
@@ -368,7 +370,7 @@ sub _get_smart_campaign_suggestion_info {
       _convert_business_profile_location($business_profile_location);
   } else {
     $suggestion_info->{businessContext} =
-      Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::BusinessContext
+      Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::BusinessContext
       ->new({
         businessName => $business_name
       });
@@ -378,7 +380,7 @@ sub _get_smart_campaign_suggestion_info {
   # example schedule describes a business that is open on Mondays from 9:00 AM
   # to 5:00 PM.
   push @{$suggestion_info->{adSchedules}},
-    Google::Ads::GoogleAds::V20::Common::AdScheduleInfo->new({
+    Google::Ads::GoogleAds::V21::Common::AdScheduleInfo->new({
       # Set the day of this schedule as Monday.
       dayOfWeek => MONDAY,
       # Set the start hour to 9 AM.
@@ -403,7 +405,7 @@ sub _get_budget_suggestion {
   my ($api_client, $customer_id, $suggestion_info) = @_;
 
   my $request =
-    Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::SuggestSmartCampaignBudgetOptionsRequest
+    Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::SuggestSmartCampaignBudgetOptionsRequest
     ->new({
       customerId => $customer_id,
       # You can retrieve suggestions for an existing campaign by setting the
@@ -444,7 +446,7 @@ sub _get_ad_suggestions {
   # Issue a request to retrieve ad creative suggestions.
   my $response =
     $api_client->SmartCampaignSuggestService()->suggest_smart_campaign_ad(
-    Google::Ads::GoogleAds::V20::Services::SmartCampaignSuggestService::SuggestSmartCampaignAdRequest
+    Google::Ads::GoogleAds::V21::Services::SmartCampaignSuggestService::SuggestSmartCampaignAdRequest
       ->new({
         customerId => $customer_id,
         # Unlike the SuggestSmartCampaignBudgetOptions method, it's only
@@ -479,17 +481,17 @@ sub _create_campaign_budget_operation {
   my ($customer_id, $suggested_budget_amount) = @_;
 
   return
-    Google::Ads::GoogleAds::V20::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V21::Services::GoogleAdsService::MutateOperation->
     new({
       campaignBudgetOperation =>
-        Google::Ads::GoogleAds::V20::Services::CampaignBudgetService::CampaignBudgetOperation
+        Google::Ads::GoogleAds::V21::Services::CampaignBudgetService::CampaignBudgetOperation
         ->new({
           create =>
-            Google::Ads::GoogleAds::V20::Resources::CampaignBudget->new({
+            Google::Ads::GoogleAds::V21::Resources::CampaignBudget->new({
               name => "Smart campaign budget #" . uniqid(),
               # A budget used for Smart campaigns must have the type SMART_CAMPAIGN.
               type =>
-                Google::Ads::GoogleAds::V20::Enums::BudgetTypeEnum::SMART_CAMPAIGN,
+                Google::Ads::GoogleAds::V21::Enums::BudgetTypeEnum::SMART_CAMPAIGN,
               # The suggested budget amount from the SmartCampaignSuggestService is
               # a daily budget. We don't need to specify that here, because the
               # budget period already defaults to DAILY.
@@ -497,7 +499,7 @@ sub _create_campaign_budget_operation {
               # Set a temporary ID in the budget's resource name so it can be
               # referenced by the campaign in later steps.
               resourceName =>
-                Google::Ads::GoogleAds::V20::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V21::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 )})})});
 }
@@ -511,12 +513,12 @@ sub _create_smart_campaign_operation {
   my ($customer_id) = @_;
 
   return
-    Google::Ads::GoogleAds::V20::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V21::Services::GoogleAdsService::MutateOperation->
     new({
       campaignOperation =>
-        Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation
+        Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation
         ->new({
-          create => Google::Ads::GoogleAds::V20::Resources::Campaign->new({
+          create => Google::Ads::GoogleAds::V21::Resources::Campaign->new({
               name => "Smart campaign #" . uniqid(),
               # Set the campaign status as PAUSED. The campaign is the only
               # entity in the mutate request that should have its status set.
@@ -525,15 +527,20 @@ sub _create_smart_campaign_operation {
               advertisingChannelType => SMART,
               # AdvertisingChannelSubType must be SMART_CAMPAIGN.
               advertisingChannelSubType =>
-                Google::Ads::GoogleAds::V20::Enums::AdvertisingChannelSubTypeEnum::SMART_CAMPAIGN,
+                Google::Ads::GoogleAds::V21::Enums::AdvertisingChannelSubTypeEnum::SMART_CAMPAIGN,
               # Assign the resource name with a temporary ID.
               resourceName =>
-                Google::Ads::GoogleAds::V20::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V21::Utils::ResourceNames::campaign(
                 $customer_id, SMART_CAMPAIGN_TEMPORARY_ID
                 ),
+              # Declare whether or not this campaign serves political ads targeting the EU.
+              # Valid values are CONTAINS_EU_POLITICAL_ADVERTISING and
+              # DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING.
+              containsEuPoliticalAdvertising =>
+                DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING,
               # Set the budget using the given budget resource name.
               campaignBudget =>
-                Google::Ads::GoogleAds::V20::Utils::ResourceNames::campaign_budget(
+                Google::Ads::GoogleAds::V21::Utils::ResourceNames::campaign_budget(
                 $customer_id, BUDGET_TEMPORARY_ID
                 )})})});
 }
@@ -548,16 +555,16 @@ sub _create_smart_campaign_setting_operation {
   my ($customer_id, $business_profile_location, $business_name) = @_;
 
   my $smart_campaign_setting =
-    Google::Ads::GoogleAds::V20::Resources::SmartCampaignSetting->new({
+    Google::Ads::GoogleAds::V21::Resources::SmartCampaignSetting->new({
       # Set a temporary ID in the campaign setting's resource name to associate it
       # with the campaign created in the previous step.
       resourceName =>
-        Google::Ads::GoogleAds::V20::Utils::ResourceNames::smart_campaign_setting(
+        Google::Ads::GoogleAds::V21::Utils::ResourceNames::smart_campaign_setting(
         $customer_id, SMART_CAMPAIGN_TEMPORARY_ID
         ),
       # Below we configure the SmartCampaignSetting using many of the same
       # details used to generate a budget suggestion.
-      phoneNumber => Google::Ads::GoogleAds::V20::Resources::PhoneNumber->new({
+      phoneNumber => Google::Ads::GoogleAds::V21::Resources::PhoneNumber->new({
           countryCode => COUNTRY_CODE,
           phoneNumber => PHONE_NUMBER
         }
@@ -576,10 +583,10 @@ sub _create_smart_campaign_setting_operation {
   }
 
   return
-    Google::Ads::GoogleAds::V20::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V21::Services::GoogleAdsService::MutateOperation->
     new({
       smartCampaignSettingOperation =>
-        Google::Ads::GoogleAds::V20::Services::SmartCampaignSettingService::SmartCampaignSettingOperation
+        Google::Ads::GoogleAds::V21::Services::SmartCampaignSettingService::SmartCampaignSettingOperation
         ->new({
           update => $smart_campaign_setting,
           # Set the update mask on the operation. This is required since the
@@ -599,16 +606,16 @@ sub _create_campaign_criterion_operations {
 
   foreach my $keyword_theme_info (@$keyword_theme_infos) {
     push @$campaign_criterion_operations,
-      Google::Ads::GoogleAds::V20::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V21::Services::GoogleAdsService::MutateOperation
       ->new({
         campaignCriterionOperation =>
-          Google::Ads::GoogleAds::V20::Services::CampaignCriterionService::CampaignCriterionOperation
+          Google::Ads::GoogleAds::V21::Services::CampaignCriterionService::CampaignCriterionOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V20::Resources::CampaignCriterion->new({
+              Google::Ads::GoogleAds::V21::Resources::CampaignCriterion->new({
                 # Set the campaign ID to a temporary ID.
                 campaign =>
-                  Google::Ads::GoogleAds::V20::Utils::ResourceNames::campaign(
+                  Google::Ads::GoogleAds::V21::Utils::ResourceNames::campaign(
                   $customer_id, SMART_CAMPAIGN_TEMPORARY_ID
                   ),
                 # Set the keyword theme to the given KeywordThemeInfo.
@@ -620,16 +627,16 @@ sub _create_campaign_criterion_operations {
   # to add corresponding location targeting to the Smart campaign.
   foreach my $location_info (@{$suggestion_info->{locationList}{locations}}) {
     push @$campaign_criterion_operations,
-      Google::Ads::GoogleAds::V20::Services::GoogleAdsService::MutateOperation
+      Google::Ads::GoogleAds::V21::Services::GoogleAdsService::MutateOperation
       ->new({
         campaignCriterionOperation =>
-          Google::Ads::GoogleAds::V20::Services::CampaignCriterionService::CampaignCriterionOperation
+          Google::Ads::GoogleAds::V21::Services::CampaignCriterionService::CampaignCriterionOperation
           ->new({
             create =>
-              Google::Ads::GoogleAds::V20::Resources::CampaignCriterion->new({
+              Google::Ads::GoogleAds::V21::Resources::CampaignCriterion->new({
                 # Set the campaign ID to a temporary ID.
                 campaign =>
-                  Google::Ads::GoogleAds::V20::Utils::ResourceNames::campaign(
+                  Google::Ads::GoogleAds::V21::Utils::ResourceNames::campaign(
                   $customer_id, SMART_CAMPAIGN_TEMPORARY_ID
                   ),
                 # Set the location to the given location.
@@ -652,21 +659,21 @@ sub _create_ad_group_operation {
   my ($customer_id) = @_;
 
   return
-    Google::Ads::GoogleAds::V20::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V21::Services::GoogleAdsService::MutateOperation->
     new({
       adGroupOperation =>
-        Google::Ads::GoogleAds::V20::Services::AdGroupService::AdGroupOperation
+        Google::Ads::GoogleAds::V21::Services::AdGroupService::AdGroupOperation
         ->new({
-          create => Google::Ads::GoogleAds::V20::Resources::AdGroup->new({
+          create => Google::Ads::GoogleAds::V21::Resources::AdGroup->new({
               # Set the ad group ID to a temporary ID.
               resourceName =>
-                Google::Ads::GoogleAds::V20::Utils::ResourceNames::ad_group(
+                Google::Ads::GoogleAds::V21::Utils::ResourceNames::ad_group(
                 $customer_id, AD_GROUP_TEMPORARY_ID
                 ),
               name => "Smart campaign ad group #" . uniqid(),
               # Set the campaign ID to a temporary ID.
               campaign =>
-                Google::Ads::GoogleAds::V20::Utils::ResourceNames::campaign(
+                Google::Ads::GoogleAds::V21::Utils::ResourceNames::campaign(
                 $customer_id, SMART_CAMPAIGN_TEMPORARY_ID
                 ),
               # The ad group type must be set to SMART_CAMPAIGN_ADS.
@@ -683,22 +690,22 @@ sub _create_ad_group_ad_operation {
   my ($customer_id, $ad_suggestions) = @_;
 
   my $mutate_operation =
-    Google::Ads::GoogleAds::V20::Services::GoogleAdsService::MutateOperation->
+    Google::Ads::GoogleAds::V21::Services::GoogleAdsService::MutateOperation->
     new({
       adGroupAdOperation =>
-        Google::Ads::GoogleAds::V20::Services::AdGroupAdService::AdGroupAdOperation
+        Google::Ads::GoogleAds::V21::Services::AdGroupAdService::AdGroupAdOperation
         ->new({
-          create => Google::Ads::GoogleAds::V20::Resources::AdGroupAd->new({
+          create => Google::Ads::GoogleAds::V21::Resources::AdGroupAd->new({
               adGroup =>
                 # Set the ad group ID to a temporary ID.
-                Google::Ads::GoogleAds::V20::Utils::ResourceNames::ad_group(
+                Google::Ads::GoogleAds::V21::Utils::ResourceNames::ad_group(
                 $customer_id, AD_GROUP_TEMPORARY_ID
                 ),
-              ad => Google::Ads::GoogleAds::V20::Resources::Ad->new({
+              ad => Google::Ads::GoogleAds::V21::Resources::Ad->new({
                   # Set the type to SMART_CAMPAIGN_AD.
                   type            => SMART_CAMPAIGN_AD,
                   smartCampaignAd =>
-                    Google::Ads::GoogleAds::V20::Common::SmartCampaignAdInfo->
+                    Google::Ads::GoogleAds::V21::Common::SmartCampaignAdInfo->
                     new({
                       headlines    => [],
                       descriptions => []})})})})});
@@ -726,7 +733,7 @@ sub _create_ad_group_ad_operation {
     REQUIRED_NUM_HEADLINES - scalar @{$smart_campaign_ad->{headlines}};
   for (my $i = 0 ; $i < $num_missing_headlines ; $i++) {
     push @{$smart_campaign_ad->{headlines}},
-      Google::Ads::GoogleAds::V20::Common::AdTextAsset->new({
+      Google::Ads::GoogleAds::V21::Common::AdTextAsset->new({
         text => "placeholder headline " . $i
       });
   }
@@ -741,7 +748,7 @@ sub _create_ad_group_ad_operation {
     REQUIRED_NUM_DESCRIPTIONS - scalar @{$smart_campaign_ad->{descriptions}};
   for (my $i = 0 ; $i < $num_missing_descriptions ; $i++) {
     push @{$smart_campaign_ad->{descriptions}},
-      Google::Ads::GoogleAds::V20::Common::AdTextAsset->new({
+      Google::Ads::GoogleAds::V21::Common::AdTextAsset->new({
         text => "placeholder description " . $i
       });
   }
