@@ -24,16 +24,18 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V20::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V20::Resources::Campaign;
-use Google::Ads::GoogleAds::V20::Resources::NetworkSettings;
-use Google::Ads::GoogleAds::V20::Common::ManualCpc;
-use Google::Ads::GoogleAds::V20::Enums::BudgetDeliveryMethodEnum   qw(STANDARD);
-use Google::Ads::GoogleAds::V20::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
-use Google::Ads::GoogleAds::V20::Enums::CampaignStatusEnum         qw(PAUSED);
+use Google::Ads::GoogleAds::V21::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V21::Resources::Campaign;
+use Google::Ads::GoogleAds::V21::Resources::NetworkSettings;
+use Google::Ads::GoogleAds::V21::Common::ManualCpc;
+use Google::Ads::GoogleAds::V21::Enums::BudgetDeliveryMethodEnum   qw(STANDARD);
+use Google::Ads::GoogleAds::V21::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
+use Google::Ads::GoogleAds::V21::Enums::CampaignStatusEnum         qw(PAUSED);
+use Google::Ads::GoogleAds::V21::Enums::EuPoliticalAdvertisingStatusEnum
+  qw(DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING);
 use
-  Google::Ads::GoogleAds::V20::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation;
+  Google::Ads::GoogleAds::V21::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -57,7 +59,7 @@ sub add_campaigns {
   # [START add_campaigns]
   # Create a campaign budget, which can be shared by multiple campaigns.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V20::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V21::Resources::CampaignBudget->new({
       name           => "Interplanetary budget #" . uniqid(),
       deliveryMethod => STANDARD,
       amountMicros   => 500000
@@ -65,7 +67,7 @@ sub add_campaigns {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V20::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V21::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({create => $campaign_budget});
 
   # Add the campaign budget.
@@ -76,7 +78,7 @@ sub add_campaigns {
 
   # [START add_campaigns_1]
   # Create a campaign.
-  my $campaign = Google::Ads::GoogleAds::V20::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V21::Resources::Campaign->new({
       name                   => "Interplanetary Cruise #" . uniqid(),
       advertisingChannelType => SEARCH,
       # Recommendation: Set the campaign to PAUSED when creating it to stop
@@ -84,11 +86,11 @@ sub add_campaigns {
       # targeting and the ads are ready to serve.
       status => PAUSED,
       # Set the bidding strategy and budget.
-      manualCpc      => Google::Ads::GoogleAds::V20::Common::ManualCpc->new(),
+      manualCpc      => Google::Ads::GoogleAds::V21::Common::ManualCpc->new(),
       campaignBudget => $campaign_budgets_response->{results}[0]{resourceName},
       # Set the campaign network options.
       networkSettings =>
-        Google::Ads::GoogleAds::V20::Resources::NetworkSettings->new({
+        Google::Ads::GoogleAds::V21::Resources::NetworkSettings->new({
           targetGoogleSearch  => "true",
           targetSearchNetwork => "true",
           # Enable Display Expansion on Search campaigns. See
@@ -97,6 +99,11 @@ sub add_campaigns {
           targetPartnerSearchNetwork => "false"
         }
         ),
+      # Declare whether or not this campaign serves political ads targeting the EU.
+      # Valid values are CONTAINS_EU_POLITICAL_ADVERTISING and
+      # DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING.
+      containsEuPoliticalAdvertising =>
+        DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING,
       # Optional: Set the start date. The campaign starts tomorrow.
       startDate => strftime("%Y%m%d", localtime(time + 60 * 60 * 24)),
       # Optional: Set the end date. The campaign runs for 30 days.
@@ -106,7 +113,7 @@ sub add_campaigns {
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation->
     new({create => $campaign});
 
   # Add the campaign.
