@@ -27,32 +27,34 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::MediaUtils;
-use Google::Ads::GoogleAds::V20::Resources::Campaign;
-use Google::Ads::GoogleAds::V20::Resources::ShoppingSetting;
-use Google::Ads::GoogleAds::V20::Resources::AdGroup;
-use Google::Ads::GoogleAds::V20::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V20::Resources::Ad;
-use Google::Ads::GoogleAds::V20::Resources::Asset;
-use Google::Ads::GoogleAds::V20::Resources::AdGroupCriterion;
-use Google::Ads::GoogleAds::V20::Common::ManualCpc;
-use Google::Ads::GoogleAds::V20::Common::ResponsiveDisplayAdInfo;
-use Google::Ads::GoogleAds::V20::Common::AdImageAsset;
-use Google::Ads::GoogleAds::V20::Common::AdTextAsset;
-use Google::Ads::GoogleAds::V20::Common::ImageAsset;
-use Google::Ads::GoogleAds::V20::Common::UserListInfo;
-use Google::Ads::GoogleAds::V20::Enums::AdvertisingChannelTypeEnum qw(DISPLAY);
-use Google::Ads::GoogleAds::V20::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V20::Enums::AdGroupStatusEnum;
-use Google::Ads::GoogleAds::V20::Enums::DisplayAdFormatSettingEnum
+use Google::Ads::GoogleAds::V21::Resources::Campaign;
+use Google::Ads::GoogleAds::V21::Resources::ShoppingSetting;
+use Google::Ads::GoogleAds::V21::Resources::AdGroup;
+use Google::Ads::GoogleAds::V21::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V21::Resources::Ad;
+use Google::Ads::GoogleAds::V21::Resources::Asset;
+use Google::Ads::GoogleAds::V21::Resources::AdGroupCriterion;
+use Google::Ads::GoogleAds::V21::Common::ManualCpc;
+use Google::Ads::GoogleAds::V21::Common::ResponsiveDisplayAdInfo;
+use Google::Ads::GoogleAds::V21::Common::AdImageAsset;
+use Google::Ads::GoogleAds::V21::Common::AdTextAsset;
+use Google::Ads::GoogleAds::V21::Common::ImageAsset;
+use Google::Ads::GoogleAds::V21::Common::UserListInfo;
+use Google::Ads::GoogleAds::V21::Enums::AdvertisingChannelTypeEnum qw(DISPLAY);
+use Google::Ads::GoogleAds::V21::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::AdGroupStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::DisplayAdFormatSettingEnum
   qw(NON_NATIVE);
-use Google::Ads::GoogleAds::V20::Enums::AssetTypeEnum qw(IMAGE);
-use Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation;
-use Google::Ads::GoogleAds::V20::Services::AdGroupService::AdGroupOperation;
-use Google::Ads::GoogleAds::V20::Services::AdGroupAdService::AdGroupAdOperation;
-use Google::Ads::GoogleAds::V20::Services::AssetService::AssetOperation;
+use Google::Ads::GoogleAds::V21::Enums::AssetTypeEnum qw(IMAGE);
+use Google::Ads::GoogleAds::V21::Enums::EuPoliticalAdvertisingStatusEnum
+  qw(DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING);
+use Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V21::Services::AdGroupService::AdGroupOperation;
+use Google::Ads::GoogleAds::V21::Services::AdGroupAdService::AdGroupAdOperation;
+use Google::Ads::GoogleAds::V21::Services::AssetService::AssetOperation;
 use
-  Google::Ads::GoogleAds::V20::Services::AdGroupCriterionService::AdGroupCriterionOperation;
-use Google::Ads::GoogleAds::V20::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V21::Services::AdGroupCriterionService::AdGroupCriterionOperation;
+use Google::Ads::GoogleAds::V21::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -105,30 +107,35 @@ sub create_campaign {
 
   # Configure the settings for the shopping campaign.
   my $shopping_settings =
-    Google::Ads::GoogleAds::V20::Resources::ShoppingSetting->new({
+    Google::Ads::GoogleAds::V21::Resources::ShoppingSetting->new({
       campaignPriority => 0,
       merchantId       => $merchant_center_account_id,
       enableLocal      => "true"
     });
 
   # Create the campaign.
-  my $campaign = Google::Ads::GoogleAds::V20::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V21::Resources::Campaign->new({
       name => "Shopping campaign #" . uniqid(),
       # Dynamic remarketing campaigns are only available on the Google Display Network.
       advertisingChannelType => DISPLAY,
-      status => Google::Ads::GoogleAds::V20::Enums::CampaignStatusEnum::PAUSED,
+      status => Google::Ads::GoogleAds::V21::Enums::CampaignStatusEnum::PAUSED,
       campaignBudget =>
-        Google::Ads::GoogleAds::V20::Utils::ResourceNames::campaign_budget(
+        Google::Ads::GoogleAds::V21::Utils::ResourceNames::campaign_budget(
         $customer_id, $campaign_budget_id
         ),
-      manualCpc => Google::Ads::GoogleAds::V20::Common::ManualCpc->new(),
+      manualCpc => Google::Ads::GoogleAds::V21::Common::ManualCpc->new(),
       # This connects the campaign to the Merchant Center account.
-      shoppingSetting => $shopping_settings
+      shoppingSetting => $shopping_settings,
+      # Declare whether or not this campaign serves political ads targeting the EU.
+      # Valid values are CONTAINS_EU_POLITICAL_ADVERTISING and
+      # DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING.
+      containsEuPoliticalAdvertising =>
+        DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING
     });
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation->
     new({create => $campaign});
 
   # Issue a mutate request to add the campaign.
@@ -149,15 +156,15 @@ sub create_ad_group {
   my ($api_client, $customer_id, $campaign_resource_name) = @_;
 
   # Create the ad group.
-  my $ad_group = Google::Ads::GoogleAds::V20::Resources::AdGroup->new({
+  my $ad_group = Google::Ads::GoogleAds::V21::Resources::AdGroup->new({
     name     => "Dynamic remarketing ad group",
     campaign => $campaign_resource_name,
-    status   => Google::Ads::GoogleAds::V20::Enums::AdGroupStatusEnum::ENABLED
+    status   => Google::Ads::GoogleAds::V21::Enums::AdGroupStatusEnum::ENABLED
   });
 
   # Create an ad group operation.
   my $ad_group_operation =
-    Google::Ads::GoogleAds::V20::Services::AdGroupService::AdGroupOperation->
+    Google::Ads::GoogleAds::V21::Services::AdGroupService::AdGroupOperation->
     new({create => $ad_group});
 
   # Issue a mutate request to add the ad group.
@@ -191,28 +198,28 @@ sub create_ad {
 
   # Create the responsive display ad info object.
   my $responsive_display_ad_info =
-    Google::Ads::GoogleAds::V20::Common::ResponsiveDisplayAdInfo->new({
+    Google::Ads::GoogleAds::V21::Common::ResponsiveDisplayAdInfo->new({
       marketingImages => [
-        Google::Ads::GoogleAds::V20::Common::AdImageAsset->new({
+        Google::Ads::GoogleAds::V21::Common::AdImageAsset->new({
             asset => $marketing_image_resource_name
           })
       ],
       squareMarketingImages => [
-        Google::Ads::GoogleAds::V20::Common::AdImageAsset->new({
+        Google::Ads::GoogleAds::V21::Common::AdImageAsset->new({
             asset => $square_marketing_image_resource_name
           })
       ],
       headlines => [
-        Google::Ads::GoogleAds::V20::Common::AdTextAsset->new({
+        Google::Ads::GoogleAds::V21::Common::AdTextAsset->new({
             text => "Travel"
           })
       ],
-      longHeadline => Google::Ads::GoogleAds::V20::Common::AdTextAsset->new({
+      longHeadline => Google::Ads::GoogleAds::V21::Common::AdTextAsset->new({
           text => "Travel the World"
         }
       ),
       descriptions => [
-        Google::Ads::GoogleAds::V20::Common::AdTextAsset->new({
+        Google::Ads::GoogleAds::V21::Common::AdTextAsset->new({
             text => "Take to the air!"
           })
       ],
@@ -229,28 +236,28 @@ sub create_ad {
       formatSetting => NON_NATIVE,
       # Optional: Create a logo image and set it to the ad.
       # logoImages => [
-      #   Google::Ads::GoogleAds::V20::Common::AdImageAsset->new({
+      #   Google::Ads::GoogleAds::V21::Common::AdImageAsset->new({
       #       asset => "INSERT_LOGO_IMAGE_RESOURCE_NAME_HERE"
       #     })
       # ],
       # Optional: Create a square logo image and set it to the ad.
       # squareLogoImages => [
-      #   Google::Ads::GoogleAds::V20::Common::AdImageAsset->new({
+      #   Google::Ads::GoogleAds::V21::Common::AdImageAsset->new({
       #       asset => "INSERT_SQUARE_LOGO_IMAGE_RESOURCE_NAME_HERE"
       #     })
       # ]
     });
 
   # Create an ad group ad.
-  my $ad_group_ad = Google::Ads::GoogleAds::V20::Resources::AdGroupAd->new({
+  my $ad_group_ad = Google::Ads::GoogleAds::V21::Resources::AdGroupAd->new({
       adGroup => $ad_group_resource_name,
-      ad      => Google::Ads::GoogleAds::V20::Resources::Ad->new({
+      ad      => Google::Ads::GoogleAds::V21::Resources::Ad->new({
           responsiveDisplayAd => $responsive_display_ad_info,
           finalUrls           => ["http://www.example.com/"]})});
 
   # Create an ad group ad operation.
   my $ad_group_ad_operation =
-    Google::Ads::GoogleAds::V20::Services::AdGroupAdService::AdGroupAdOperation
+    Google::Ads::GoogleAds::V21::Services::AdGroupAdService::AdGroupAdOperation
     ->new({create => $ad_group_ad});
 
   # Issue a mutate request to add the ad group ad.
@@ -270,16 +277,16 @@ sub upload_asset {
   my $image_data = get_base64_data_from_url($image_url);
 
   # Create an asset.
-  my $asset = Google::Ads::GoogleAds::V20::Resources::Asset->new({
+  my $asset = Google::Ads::GoogleAds::V21::Resources::Asset->new({
       name       => $asset_name,
       type       => IMAGE,
-      imageAsset => Google::Ads::GoogleAds::V20::Common::ImageAsset->new({
+      imageAsset => Google::Ads::GoogleAds::V21::Common::ImageAsset->new({
           data => $image_data
         })});
 
   # Create an asset operation.
   my $asset_operation =
-    Google::Ads::GoogleAds::V20::Services::AssetService::AssetOperation->new({
+    Google::Ads::GoogleAds::V21::Services::AssetService::AssetOperation->new({
       create => $asset
     });
 
@@ -302,17 +309,17 @@ sub attach_user_list {
 
   # Create the ad group criterion that targets the user list.
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V20::Resources::AdGroupCriterion->new({
+    Google::Ads::GoogleAds::V21::Resources::AdGroupCriterion->new({
       adGroup  => $ad_group_resource_name,
-      userList => Google::Ads::GoogleAds::V20::Common::UserListInfo->new({
+      userList => Google::Ads::GoogleAds::V21::Common::UserListInfo->new({
           userList =>
-            Google::Ads::GoogleAds::V20::Utils::ResourceNames::user_list(
+            Google::Ads::GoogleAds::V21::Utils::ResourceNames::user_list(
             $customer_id, $user_list_id
             )})});
 
   # Create an ad group criterion operation.
   my $ad_group_criterion_operation =
-    Google::Ads::GoogleAds::V20::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V21::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({create => $ad_group_criterion});
 
   # Issue a mutate request to add the ad group criterion.
