@@ -30,32 +30,34 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V20::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V20::Resources::Campaign;
-use Google::Ads::GoogleAds::V20::Resources::ShoppingSetting;
-use Google::Ads::GoogleAds::V20::Resources::AdGroup;
-use Google::Ads::GoogleAds::V20::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V20::Resources::Ad;
-use Google::Ads::GoogleAds::V20::Resources::AdGroupCriterion;
-use Google::Ads::GoogleAds::V20::Common::ManualCpc;
-use Google::Ads::GoogleAds::V20::Common::ShoppingProductAdInfo;
-use Google::Ads::GoogleAds::V20::Common::ListingGroupInfo;
-use Google::Ads::GoogleAds::V20::Enums::BudgetDeliveryMethodEnum   qw(STANDARD);
-use Google::Ads::GoogleAds::V20::Enums::AdvertisingChannelTypeEnum qw(SHOPPING);
-use Google::Ads::GoogleAds::V20::Enums::AdGroupTypeEnum
+use Google::Ads::GoogleAds::V21::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V21::Resources::Campaign;
+use Google::Ads::GoogleAds::V21::Resources::ShoppingSetting;
+use Google::Ads::GoogleAds::V21::Resources::AdGroup;
+use Google::Ads::GoogleAds::V21::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V21::Resources::Ad;
+use Google::Ads::GoogleAds::V21::Resources::AdGroupCriterion;
+use Google::Ads::GoogleAds::V21::Common::ManualCpc;
+use Google::Ads::GoogleAds::V21::Common::ShoppingProductAdInfo;
+use Google::Ads::GoogleAds::V21::Common::ListingGroupInfo;
+use Google::Ads::GoogleAds::V21::Enums::BudgetDeliveryMethodEnum   qw(STANDARD);
+use Google::Ads::GoogleAds::V21::Enums::AdvertisingChannelTypeEnum qw(SHOPPING);
+use Google::Ads::GoogleAds::V21::Enums::AdGroupTypeEnum
   qw(SHOPPING_PRODUCT_ADS);
-use Google::Ads::GoogleAds::V20::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V20::Enums::AdGroupStatusEnum;
-use Google::Ads::GoogleAds::V20::Enums::AdGroupAdStatusEnum;
-use Google::Ads::GoogleAds::V20::Enums::ListingGroupTypeEnum qw(UNIT);
-use Google::Ads::GoogleAds::V20::Enums::AdGroupCriterionStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::AdGroupStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::AdGroupAdStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::ListingGroupTypeEnum qw(UNIT);
+use Google::Ads::GoogleAds::V21::Enums::AdGroupCriterionStatusEnum;
+use Google::Ads::GoogleAds::V21::Enums::EuPoliticalAdvertisingStatusEnum
+  qw(DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING);
 use
-  Google::Ads::GoogleAds::V20::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation;
-use Google::Ads::GoogleAds::V20::Services::AdGroupService::AdGroupOperation;
-use Google::Ads::GoogleAds::V20::Services::AdGroupAdService::AdGroupAdOperation;
+  Google::Ads::GoogleAds::V21::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V21::Services::AdGroupService::AdGroupOperation;
+use Google::Ads::GoogleAds::V21::Services::AdGroupAdService::AdGroupAdOperation;
 use
-  Google::Ads::GoogleAds::V20::Services::AdGroupCriterionService::AdGroupCriterionOperation;
+  Google::Ads::GoogleAds::V21::Services::AdGroupCriterionService::AdGroupCriterionOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -113,7 +115,7 @@ sub add_campaign_budget {
 
   # Create a campaign budget.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V20::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V21::Resources::CampaignBudget->new({
       name           => "Interplanetary Cruise Budget #" . uniqid(),
       deliveryMethod => STANDARD,
       # Set the amount of budget.
@@ -122,7 +124,7 @@ sub add_campaign_budget {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V20::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V21::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({create => $campaign_budget});
 
   # Add the campaign budget.
@@ -145,13 +147,13 @@ sub add_standard_shopping_campaign {
     = @_;
 
   # Create a standard shopping campaign.
-  my $campaign = Google::Ads::GoogleAds::V20::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V21::Resources::Campaign->new({
       name => "Interplanetary Cruise Campaign #" . uniqid(),
       # Configure settings related to shopping campaigns including advertising
       # channel type and shopping setting.
       advertisingChannelType => SHOPPING,
       shoppingSetting        =>
-        Google::Ads::GoogleAds::V20::Resources::ShoppingSetting->new({
+        Google::Ads::GoogleAds::V21::Resources::ShoppingSetting->new({
           merchantId => $merchant_center_account_id,
           # Set the priority of the campaign. Higher numbers take priority over
           # lower numbers. For standard shopping campaigns, allowed values are
@@ -164,19 +166,24 @@ sub add_standard_shopping_campaign {
       # Recommendation: Set the campaign to PAUSED when creating it to prevent
       # the ads from immediately serving. Set to ENABLED once you've added
       # targeting and the ads are ready to serve.
-      status => Google::Ads::GoogleAds::V20::Enums::CampaignStatusEnum::PAUSED,
+      status => Google::Ads::GoogleAds::V21::Enums::CampaignStatusEnum::PAUSED,
       # Set the bidding strategy to Manual CPC.
       # Recommendation: Use one of the automated bidding strategies for shopping
       # campaigns to help you optimize your advertising spend. More information
       # can be found here: https://support.google.com/google-ads/answer/6309029.
-      manualCpc => Google::Ads::GoogleAds::V20::Common::ManualCpc->new(),
+      manualCpc => Google::Ads::GoogleAds::V21::Common::ManualCpc->new(),
       # Set the budget.
-      campaignBudget => $budget_resource_name
+      campaignBudget => $budget_resource_name,
+      # Declare whether or not this campaign serves political ads targeting the EU.
+      # Valid values are CONTAINS_EU_POLITICAL_ADVERTISING and
+      # DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING.
+      containsEuPoliticalAdvertising =>
+        DOES_NOT_CONTAIN_EU_POLITICAL_ADVERTISING
     });
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V20::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V21::Services::CampaignService::CampaignOperation->
     new({create => $campaign});
 
   # Add the campaign.
@@ -197,19 +204,19 @@ sub add_shopping_product_ad_group {
   my ($api_client, $customer_id, $campaign_resource_name) = @_;
 
   # Create an ad group.
-  my $ad_group = Google::Ads::GoogleAds::V20::Resources::AdGroup->new({
+  my $ad_group = Google::Ads::GoogleAds::V21::Resources::AdGroup->new({
     name     => "Earth to Mars Cruises #" . uniqid(),
     campaign => $campaign_resource_name,
     # Set the ad group type to SHOPPING_PRODUCT_ADS. This is the only value
     # possible for ad groups that contain shopping product ads.
     type         => SHOPPING_PRODUCT_ADS,
     cpcBidMicros => 1000000,
-    status => Google::Ads::GoogleAds::V20::Enums::AdGroupStatusEnum::ENABLED
+    status => Google::Ads::GoogleAds::V21::Enums::AdGroupStatusEnum::ENABLED
   });
 
   # Create an ad group operation.
   my $ad_group_operation =
-    Google::Ads::GoogleAds::V20::Services::AdGroupService::AdGroupOperation->
+    Google::Ads::GoogleAds::V21::Services::AdGroupService::AdGroupOperation->
     new({create => $ad_group});
 
   # Add the ad group.
@@ -230,20 +237,20 @@ sub add_shopping_product_ad_group_ad {
   my ($api_client, $customer_id, $ad_group_resource_name) = @_;
 
   # Create an ad group ad and set a shopping product ad to it.
-  my $ad_group_ad = Google::Ads::GoogleAds::V20::Resources::AdGroupAd->new({
+  my $ad_group_ad = Google::Ads::GoogleAds::V21::Resources::AdGroupAd->new({
       # Set the ad group.
       adGroup => $ad_group_resource_name,
       # Set the ad to a new shopping product ad.
-      ad => Google::Ads::GoogleAds::V20::Resources::Ad->new({
+      ad => Google::Ads::GoogleAds::V21::Resources::Ad->new({
           shoppingProductAd =>
-            Google::Ads::GoogleAds::V20::Common::ShoppingProductAdInfo->new()}
+            Google::Ads::GoogleAds::V21::Common::ShoppingProductAdInfo->new()}
       ),
-      status => Google::Ads::GoogleAds::V20::Enums::AdGroupAdStatusEnum::PAUSED
+      status => Google::Ads::GoogleAds::V21::Enums::AdGroupAdStatusEnum::PAUSED
     });
 
   # Create an ad group ad operation.
   my $ad_group_ad_operation =
-    Google::Ads::GoogleAds::V20::Services::AdGroupAdService::AdGroupAdOperation
+    Google::Ads::GoogleAds::V21::Services::AdGroupAdService::AdGroupAdOperation
     ->new({create => $ad_group_ad});
 
   # Add the ad group ad.
@@ -268,25 +275,25 @@ sub add_default_shopping_listing_group {
   # Create a new ad group criterion. This will contain the "default" listing group
   # (All products).
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V20::Resources::AdGroupCriterion->new({
+    Google::Ads::GoogleAds::V21::Resources::AdGroupCriterion->new({
       # Set the ad group.
       adGroup => $ad_group_resource_name,
       # Create a new listing group. This will be the top-level "root" node.
       # Set the type of the listing group to be a biddable unit.
       listingGroup =>
-        Google::Ads::GoogleAds::V20::Common::ListingGroupInfo->new({
+        Google::Ads::GoogleAds::V21::Common::ListingGroupInfo->new({
           type => UNIT
         }
         ),
       # Set the bid for products in this listing group unit.
       cpcBidMicros => 500000,
       status       =>
-        Google::Ads::GoogleAds::V20::Enums::AdGroupCriterionStatusEnum::ENABLED
+        Google::Ads::GoogleAds::V21::Enums::AdGroupCriterionStatusEnum::ENABLED
     });
 
   # Create an ad group criterion operation.
   my $ad_group_criterion_operation =
-    Google::Ads::GoogleAds::V20::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V21::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({create => $ad_group_criterion});
 
   # Add the listing group criterion.
@@ -294,7 +301,7 @@ sub add_default_shopping_listing_group {
     $api_client->AdGroupCriterionService()->mutate({
       customerId => $customer_id,
       operations => [$ad_group_criterion_operation]}
-  )->{results}[0]{resourceName};
+    )->{results}[0]{resourceName};
 
   printf "Added an ad group criterion containing a listing group " .
     "with resource name: '%s'.\n", $ad_group_criterion_resource_name;
